@@ -17,11 +17,8 @@
  * limitations under the License.
  * #L%
  */
-
 package org.scijava.notebook.converter.output;
 
-import com.twosigma.beaker.mimetype.MIMEContainer;
-
 /**
  *
  * @author Hadrien Mary
@@ -29,7 +26,7 @@ import com.twosigma.beaker.mimetype.MIMEContainer;
 public class PNGImageNotebookOutput extends ImageNotebookOutput {
 
     public PNGImageNotebookOutput(String content) {
-        super(MIMEContainer.MIME.IMAGE_PNG, content);
+	super("image/png", content);
     }
 
 }
